darkhistory.spec — DarkHistory documentation

# darkhistory.spec

Classes and functions for manipulating spectra.

Modules

`pppc` | PPPC4DMID [1] [2] Information and Functions.
`spectools` | Functions useful for processing spectral data.
`spectra` | Contains the Spectra class.
`spectrum` | Contains the Spectrum class.
`transferfunclist` | Functions and classes for processing lists of transfer functions.
`transferfunction` | Functions and classes for processing transfer functions.

Footnotes

[1] | Marco Cirelli, Gennaro Corcella, Andi Hektor, Gert Hutsi, Mario Kadastik, Paolo Panci, Martti Raidal, Filippo Sala, and Alessandro Strumia, “PPPC 4 DM ID: A Poor Particle Physicist Cookbook for Dark Matter Indirect Detection,” JCAP 1103, 051 (2011), [Erratum: JCAP1210,E01(2012)], arXiv:1012.4515 [hep-ph].

[2] | Paolo Ciafaloni, Denis Comelli, Antonio Riotto, Filippo Sala, Alessandro Strumia, et al., “Weak Corrections are Relevant for Dark Matter Indirect Detection,” JCAP 1103, 019 (2011), arXiv:1009.0224 [hep-ph]

#### Previous topic

darkhistory.low_energy.lowE_photons.kappa_DM

#### Next topic

darkhistory.spec.pppc

### This Page

Show Source